@@ -1,6 +1,6 @@
 #!/bin/sh
 
-. $TOP/makegen/makegen.cf
+. $MACRO_DIR/makegen/makegen.cf
 
 DIR=$1
 TARGETS=`echo $2 | sed "s/,/ /g"`
