@@ -110,7 +110,8 @@ mindex_t *loadIndices(table,db)
                 fd;
 
         msqlTrace(TRACE_IN,"loadIndices()");
-        (void)sprintf(path,"%s/msqldb/%s/%s.idx",msqlHomeDir,db,table);
+        (void)snprintf(path,MAXPATHLEN,"%s/msqldb/%s/%s.idx",
+		msqlHomeDir,db,table);
 #ifdef OS2
         fd = _sopen(path ,O_RDONLY | O_BINARY, SH_DENYNO, S_IREAD | S_IWRITE);
 #else
@@ -118,7 +119,8 @@ mindex_t *loadIndices(table,db)
 #endif
         if (fd < 0)
         {
-                sprintf(errMsg,"Can't open index definition for '%s'",table);
+                snprintf(errMsg,MAX_ERR_MSG, 
+			"Can't open index definition for '%s'",table);
                 msqlTrace(TRACE_OUT,"loadIndices()");
                 return(NULL);
         }
@@ -128,7 +130,7 @@ mindex_t *loadIndices(table,db)
 	{
         	if (numBytes < sizeof(buf))
         	{
-                	sprintf(errMsg,TABLE_READ_ERROR,table,
+                	snprintf(errMsg,MAX_ERR_MSG, TABLE_READ_ERROR,table,
 				(char*)strerror(errno));
                 	msqlDebug(MOD_ERR,
 				"Error reading \"%s\" index definition\n",
@@ -169,8 +171,8 @@ mindex_t *loadIndices(table,db)
 				curIndex->next = NULL;
 			}
                 }
-		sprintf(path,"%s/msqldb/%s/%s.idx-%s",msqlHomeDir,db,table,
-			curIndex->name);
+		snprintf(path,MAXPATHLEN,"%s/msqldb/%s/%s.idx-%s",
+			msqlHomeDir,db,table, curIndex->name);
 		curIndex->tree = avlOpen(path);
 		curIndex->buf = (char *)malloc(curIndex->length + 1);
         	numBytes = read(fd,&buf,sizeof(buf));
@@ -260,7 +262,8 @@ static int fillIndexBuffer(index,fields)
 		if (copyValue(cp,curField->value,curField->type,
 			curField->length,0) < 0)
 		{
-			sprintf(errMsg,NULL_JOIN_COND_ERR,curField->name);
+			snprintf(errMsg,MAX_ERR_MSG,NULL_JOIN_COND_ERR,
+				curField->name);
 			return(-1);
 		}
 		cp += curField->length;
@@ -586,7 +589,7 @@ int checkIndexNullFields(entry,row,index,flist)
 		}
                	if (!*(data + *offset))
                	{
-                       	sprintf(errMsg,NULL_INDEX_ERROR, 
+                       	snprintf(errMsg,MAX_ERR_MSG, NULL_INDEX_ERROR, 
 				curField->name);
                        	msqlTrace(TRACE_OUT,"checkIndexNullFields()");
                        	return(-1);
@@ -621,6 +624,44 @@ int checkIndicesNullFields(entry,row, flist)
 
 
 
+static void extractFieldValue(buf,cond)
+	char	*buf;
+	cond_t	*cond;
+{
+	int	length;
+
+	switch(cond->value->type)
+	{
+		case INT_TYPE:
+		case UINT_TYPE:
+		case DATE_TYPE:
+		case MONEY_TYPE:
+		case TIME_TYPE:
+			bcopy(&(cond->value->val.intVal),buf,4);
+			break;
+
+
+		case REAL_TYPE:
+			bcopy(&(cond->value->val.realVal),buf,8);
+			break;
+
+		case CHAR_TYPE:
+			length = strlen((char *)cond->value->val.charVal);
+			if (length > cond->length)
+				length = cond->length;
+			bcopy((char *)cond->value->val.charVal,buf,length);
+			break;
+	}
+}
+
+
+
+
+
+
+/*
+** This is the mSQL 2.0 CRA code
+*/
 
 
 void freeCandidate(cand)
@@ -696,7 +737,8 @@ int setCandidateValues(inner, cand, fields, conds, row)
 				if (copyValue(cp,curField->value,curField->type,
 					curField->length,0) < 0)
 				{
-					sprintf(errMsg,NULL_JOIN_COND_ERR,
+					snprintf(errMsg,MAX_ERR_MSG,
+						NULL_JOIN_COND_ERR,
 						curField->name);
 					return(-1);
 				}
@@ -731,7 +773,7 @@ int setCandidateValues(inner, cand, fields, conds, row)
 					if(copyValue(cp,tmpField.value,
 					     tmpField.type,tmpField.length,0)<0)
 					{
-						sprintf(errMsg,
+						snprintf(errMsg,MAX_ERR_MSG,
 							NULL_JOIN_COND_ERR,
 							curField->name);
 						return(-1);
@@ -746,7 +788,7 @@ int setCandidateValues(inner, cand, fields, conds, row)
 					if(copyValue(cp,curCond->value,
 					     curCond->type,curCond->length,0)<0)
 					{
-						sprintf(errMsg,
+						snprintf(errMsg,MAX_ERR_MSG,
 							NULL_JOIN_COND_ERR,
 							curField->name);
 						return(-1);
@@ -773,41 +815,6 @@ int setCandidateValues(inner, cand, fields, conds, row)
 
 
 
-
-static void extractFieldValue(buf,cond)
-	char	*buf;
-	cond_t	*cond;
-{
-	int	length;
-
-	switch(cond->value->type)
-	{
-		case INT_TYPE:
-		case UINT_TYPE:
-		case DATE_TYPE:
-		case MONEY_TYPE:
-		case TIME_TYPE:
-			bcopy(&(cond->value->val.intVal),buf,4);
-			break;
-
-
-		case REAL_TYPE:
-			bcopy(&(cond->value->val.realVal),buf,8);
-			break;
-
-		case CHAR_TYPE:
-			length = strlen((char *)cond->value->val.charVal);
-			if (length > cond->length)
-				length = cond->length;
-			bcopy((char *)cond->value->val.charVal,buf,length);
-			break;
-	}
-}
-
-
-
-
-
 cand_t *msqlSetupCandidate(entry, conds, fields, ignoreIdent)
 	cache_t	*entry;
 	cond_t	*conds;
@@ -1019,7 +1026,7 @@ cand_t *msqlSetupCandidate(entry, conds, fields, ignoreIdent)
 				{
 					if (curCond->value->nullVal)
 					{
-                				sprintf(errMsg,
+                				snprintf(errMsg,MAX_ERR_MSG,
 							NULL_COND_ERR, 
 							curCond->name);
                					return(NULL);
@@ -1164,3 +1171,4 @@ u_int getCandidate(entry, cand)
 	}
 	return(NO_POS);
 }
+
