@@ -58,7 +58,7 @@ int main(argc,argv)
 	oldTime = time(NULL);
 	while (count < num)
 	{
-		sprintf(qbuf,INSERT_QUERY,count,count);
+		snprintf(qbuf,sizeof(qbuf),INSERT_QUERY,count,count);
 		if(msqlQuery(sock,qbuf) < 0)
 		{
 			printf("Query failed for count=%d(%s)\n",count,
