@@ -196,7 +196,7 @@ ident_t *msqlCreateIdent(seg1,seg2)
 	{
 		if ((int)strlen(seg1) > NAME_LEN)
 		{
-			sprintf(packet,
+			snprintf(packet,PKT_LEN,
 				"-1:Identifier name '%s' too long\n",seg1);
 			writePkt(outSock);
 			msqlTrace(TRACE_OUT,"msqlCreateIdent()");
@@ -207,7 +207,7 @@ ident_t *msqlCreateIdent(seg1,seg2)
 	{
 		if ((int)strlen(seg2) > NAME_LEN)
 		{
-			sprintf(packet,
+			snprintf(packet,PKT_LEN,
 				"-1:Identifier name '%s' too long\n",seg2);
 			writePkt(outSock);
 			msqlTrace(TRACE_OUT,"msqlCreateIdent()");
@@ -559,7 +559,7 @@ int msqlAddField(ident,type,length,notNull,priKey)
 		{
 			if (strcmp(new->name,name) == 0)
 			{
-				sprintf(packet,
+				snprintf(packet,PKT_LEN,
 					"-1:Duplicate field name '%s'\n",
 					name);
 				writePkt(outSock);
@@ -572,7 +572,7 @@ int msqlAddField(ident,type,length,notNull,priKey)
 
 	if (priKey)
 	{
-		sprintf(packet,
+		snprintf(packet,PKT_LEN,
 			"-1:Primary keys are obsolete.  Use CREATE INDEX\n");
 		writePkt(outSock);
 		msqlTrace(TRACE_OUT,"msqlAddField()");
@@ -920,7 +920,7 @@ void msqlProcessQuery()
 	msqlTrace(TRACE_IN,"msqlProcessQuery()");
 	if (!curDB)
 	{
-		sprintf(packet,"-1:No current database\n");
+		strcpy(packet,"-1:No current database\n");
 		writePkt(outSock);
 		msqlDebug(MOD_ERR,"No current database\n");
 		msqlTrace(TRACE_OUT,"msqlProcessQuery()");
@@ -932,7 +932,7 @@ void msqlProcessQuery()
 		case MSQL_SELECT: 
 			if (!msqlCheckPerms(READ_ACCESS))
 			{
-				sprintf(packet,"-1:Access Denied\n");
+				strcpy(packet,"-1:Access Denied\n");
 				writePkt(outSock);
 				msqlTrace(TRACE_OUT,"msqlProcessQuery()");
 				return;
@@ -943,7 +943,7 @@ void msqlProcessQuery()
 		case CREATE_TABLE: 
 			if (!msqlCheckPerms(WRITE_ACCESS) || readOnly)
 			{
-				sprintf(packet,"-1:Access Denied\n");
+				strcpy(packet,"-1:Access Denied\n");
 				writePkt(outSock);
 				msqlTrace(TRACE_OUT,"msqlProcessQuery()");
 				return;
@@ -954,7 +954,7 @@ void msqlProcessQuery()
 		case CREATE_INDEX: 
 			if (!msqlCheckPerms(WRITE_ACCESS) || readOnly)
 			{
-				sprintf(packet,"-1:Access Denied\n");
+				strcpy(packet,"-1:Access Denied\n");
 				writePkt(outSock);
 				msqlTrace(TRACE_OUT,"msqlProcessQuery()");
 				return;
@@ -964,7 +964,7 @@ void msqlProcessQuery()
 		case CREATE_SEQUENCE: 
 			if (!msqlCheckPerms(WRITE_ACCESS) || readOnly)
 			{
-				sprintf(packet,"-1:Access Denied\n");
+				strcpy(packet,"-1:Access Denied\n");
 				writePkt(outSock);
 				msqlTrace(TRACE_OUT,"msqlProcessQuery()");
 				return;
@@ -975,7 +975,7 @@ void msqlProcessQuery()
 		case MSQL_UPDATE: 
 			if (!msqlCheckPerms(RW_ACCESS) || readOnly)
 			{
-				sprintf(packet,"-1:Access Denied\n");
+				strcpy(packet,"-1:Access Denied\n");
 				writePkt(outSock);
 				msqlTrace(TRACE_OUT,"msqlProcessQuery()");
 				return;
@@ -986,7 +986,7 @@ void msqlProcessQuery()
 		case MSQL_INSERT: 
 			if (!msqlCheckPerms(WRITE_ACCESS) || readOnly)
 			{
-				sprintf(packet,"-1:Access Denied\n");
+				strcpy(packet,"-1:Access Denied\n");
 				writePkt(outSock);
 				msqlTrace(TRACE_OUT,"msqlProcessQuery()");
 				return;
@@ -996,7 +996,7 @@ void msqlProcessQuery()
 		case MSQL_DELETE: 
 			if (!msqlCheckPerms(WRITE_ACCESS) || readOnly)
 			{
-				sprintf(packet,"-1:Access Denied\n");
+				strcpy(packet,"-1:Access Denied\n");
 				writePkt(outSock);
 				msqlTrace(TRACE_OUT,"msqlProcessQuery()");
 				return;
@@ -1006,7 +1006,7 @@ void msqlProcessQuery()
 		case DROP_TABLE: 
 			if (!msqlCheckPerms(WRITE_ACCESS) || readOnly)
 			{
-				sprintf(packet,"-1:Access Denied\n");
+				strcpy(packet,"-1:Access Denied\n");
 				writePkt(outSock);
 				msqlTrace(TRACE_OUT,"msqlProcessQuery()");
 				return;
@@ -1016,7 +1016,7 @@ void msqlProcessQuery()
 		case DROP_INDEX: 
 			if (!msqlCheckPerms(WRITE_ACCESS) || readOnly)
 			{
-				sprintf(packet,"-1:Access Denied\n");
+				strcpy(packet,"-1:Access Denied\n");
 				writePkt(outSock);
 				msqlTrace(TRACE_OUT,"msqlProcessQuery()");
 				return;
@@ -1026,7 +1026,7 @@ void msqlProcessQuery()
 		case DROP_SEQUENCE: 
 			if (!msqlCheckPerms(WRITE_ACCESS) || readOnly)
 			{
-				sprintf(packet,"-1:Access Denied\n");
+				strcpy(packet,"-1:Access Denied\n");
 				writePkt(outSock);
 				msqlTrace(TRACE_OUT,"msqlProcessQuery()");
 				return;
@@ -1038,7 +1038,7 @@ void msqlProcessQuery()
 	{
 		extern	char	errMsg[];
 
-		sprintf(packet,"-1:%s\n",errMsg);
+		snprintf(packet,PKT_LEN,"-1:%s\n",errMsg);
 		msqlTrace(TRACE_OUT,"msqlProcessQuery()");
 		writePkt(outSock);
 	}
@@ -1051,7 +1051,8 @@ void msqlQueryOverrunError(txt)
 {
 
 	msqlTrace(TRACE_IN,"msqlQueryOverrunError()");
-	sprintf(packet,"-1:Syntax error.  Bad text after query. '%s'\n",txt);
+	snprintf(packet,PKT_LEN,
+		"-1:Syntax error.  Bad text after query. '%s'\n",txt);
 	writePkt(outSock);
 	msqlTrace(TRACE_OUT,"msqlQueryOverrunError()");
 }
