@@ -95,7 +95,7 @@ extern	char	*packet;
 int	selectWildcard = 0,
 	selectDistinct = 0;
 
-char	errMsg[200];
+char	errMsg[MAX_ERR_MSG];
 char	*msqlHomeDir;
 
 cache_t *loadTableDef();
@@ -136,11 +136,12 @@ void msqlServerListDBs(sock)
 #endif
 
 	msqlTrace(TRACE_IN,"msqlListDBs()");
-	(void)sprintf(path,"%s/msqldb",msqlHomeDir);
+	(void)snprintf(path, MAXPATHLEN, "%s/msqldb",msqlHomeDir);
 	dirp = opendir(path);
 	if (!dirp)
 	{
-		sprintf(errMsg,BAD_DIR_ERROR,path, (char*)strerror(errno));
+		snprintf(errMsg,MAX_ERR_MSG,BAD_DIR_ERROR,path, 
+			(char*)strerror(errno));
 		msqlDebug(MOD_ERR,"Can't open directory \"%s\"\n",path);
 		msqlTrace(TRACE_OUT,"msqlListDBs()");
 		return;
@@ -158,11 +159,12 @@ void msqlServerListDBs(sock)
 			cur = readdir(dirp);
 			continue;
 		}
-		sprintf(packet,"%d:%s\n",(int)strlen(cur->d_name),cur->d_name);
+		snprintf(packet,PKT_LEN, "%d:%s\n",(int)strlen(cur->d_name),
+			cur->d_name);
 		writePkt(sock);
 		cur = readdir(dirp);
 	}
-	sprintf(packet,"-100:\n");
+	strcpy(packet,"-100:\n");
 	writePkt(sock);
 	closedir(dirp);
 	msqlTrace(TRACE_OUT,"msqlListDBs()");
@@ -197,11 +199,12 @@ void msqlServerListTables(sock,db)
 #endif
 
 	msqlTrace(TRACE_IN,"msqlListTables()");
-	(void)sprintf(path,"%s/msqldb/%s",msqlHomeDir,db);
+	(void)snprintf(path,MAXPATHLEN,"%s/msqldb/%s",msqlHomeDir,db);
 	dirp = opendir(path);
 	if (!dirp)
 	{
-		sprintf(errMsg,BAD_DIR_ERROR,path, (char*)strerror(errno));
+		snprintf(errMsg,MAX_ERR_MSG,BAD_DIR_ERROR,path, 
+			(char*)strerror(errno));
 		msqlDebug(MOD_ERR,"Can't open directory \"%s\"\n",path);
 		msqlTrace(TRACE_OUT,"msqlListTables()");
 		return;
@@ -234,13 +237,13 @@ void msqlServerListTables(sock,db)
 		if (strcmp(cp,".def") == 0)
 		{
 			*cp = 0;
-			sprintf(packet,"%d:%s\n",
+			snprintf(packet,PKT_LEN, "%d:%s\n",
 				(int)strlen(cur->d_name),cur->d_name);
 			writePkt(sock);
 		}
 		cur = readdir(dirp);
 	}
-	sprintf(packet,"-100:\n");
+	strcpy(packet,"-100:\n");
 	writePkt(sock);
 	closedir(dirp);
 	msqlTrace(TRACE_OUT,"msqlListTables()");
@@ -271,19 +274,19 @@ void msqlServerSequenceInfo(sock,table,db)
 	{
 		if (cacheEntry->sblk->sequence.step)
 		{
-			sprintf(packet,"1:%d:%d",
+			snprintf(packet,PKT_LEN,"1:%d:%d",
 				cacheEntry->sblk->sequence.step,
 				cacheEntry->sblk->sequence.value);
 		}
 		else
 		{
-			sprintf(packet,"-1:No sequence defined on '%s'\n",
-				table);
+			snprintf(packet,PKT_LEN, 
+				"-1:No sequence defined on '%s'\n", table);
 		}
 	}
 	else
 	{
-		sprintf(packet,"-1:%s\n",errMsg);
+		snprintf(packet,PKT_LEN,"-1:%s\n",errMsg);
 	}
 	writePkt(sock);
 	msqlTrace(TRACE_OUT,"msqlServerSequenceInfo()");
@@ -318,9 +321,9 @@ void msqlServerListFields(sock,table,db)
       		curField = cacheEntry->def;
 		while(curField)
 		{
-			sprintf(buf,"%d",curField->length);
-			sprintf(buf2,"%d",curField->type);
-			sprintf(packet,"%d:%s%d:%s%d:%s%d:%s1:%s1:%s", 
+			snprintf(buf,sizeof(buf),"%d",curField->length);
+			snprintf(buf2,sizeof(buf2),"%d",curField->type);
+			snprintf(packet,PKT_LEN,"%d:%s%d:%s%d:%s%d:%s1:%s1:%s", 
 				(int)strlen(table), table,
 				(int)strlen(curField->name), curField->name, 
 				(int)strlen(buf2), buf2,
@@ -333,8 +336,8 @@ void msqlServerListFields(sock,table,db)
       		curIndex = cacheEntry->indices;
 		while(curIndex)
 		{
-			sprintf(buf2,"%d",IDX_TYPE);
-			sprintf(packet,"%d:%s%d:%s%d:%s%d:%s1:%s1:%s", 
+			snprintf(buf2,sizeof(buf2),"%d",IDX_TYPE);
+			snprintf(packet,PKT_LEN,"%d:%s%d:%s%d:%s%d:%s1:%s1:%s", 
 				(int)strlen(table), table,
 				(int)strlen(curIndex->name), curIndex->name, 
 				(int)strlen(buf2), buf2,
@@ -343,12 +346,12 @@ void msqlServerListFields(sock,table,db)
 			writePkt(sock);
 			curIndex = curIndex->next;
 		}
-		sprintf(packet,"-100:\n");
+		strcpy(packet,"-100:\n");
 		writePkt(sock);
 	}
 	else
 	{
-		sprintf(packet,"-1:Unknown table '%s'\n", table);
+		snprintf(packet,PKT_LEN,"-1:Unknown table '%s'\n", table);
 		writePkt(sock);
 	}
 	msqlTrace(TRACE_OUT,"msqlListFields()");
@@ -408,7 +411,8 @@ void msqlServerListIndex(sock,index,table,db)
 					idxType = "???";
 					break;
 			}
-			sprintf(packet,"%d:%s\n",(int)strlen(idxType),idxType);
+			snprintf(packet,PKT_LEN,"%d:%s\n",(int)strlen(idxType),
+				idxType);
 			writePkt(sock);
 			if (curIndex)
 			{
@@ -422,7 +426,7 @@ void msqlServerListIndex(sock,index,table,db)
 						curField = curField->next;
 						offset--;
 					}
-					sprintf(packet,"%d:%s\n",
+					snprintf(packet,PKT_LEN,"%d:%s\n",
 						(int)strlen(curField->name),
 						curField->name);
 					count ++;
@@ -431,7 +435,7 @@ void msqlServerListIndex(sock,index,table,db)
 			}
 		}
 	}
-	sprintf(packet,"-100:\n");
+	strcpy(packet,"-100:\n");
 	writePkt(sock);
 	msqlTrace(TRACE_OUT,"msqlListFields()");
 }
@@ -552,7 +556,8 @@ static int checkNullFields(cacheEntry,row, flist)
 	{
 		if (!*(data + *curfl) && (curField->flags & NOT_NULL_FLAG))
 		{
-			sprintf(errMsg,BAD_NULL_ERROR, curField->name);
+			snprintf(errMsg,MAX_ERR_MSG,BAD_NULL_ERROR, 
+				curField->name);
 			msqlDebug(MOD_ERR,"Field \"%s\" cannot be null\n",
 				curField->name);
 			msqlTrace(TRACE_OUT,"checkNullFields()");
@@ -676,7 +681,7 @@ int msqlSetupFields(cacheEntry,flist, fields)
 	}
 	if (numFields > MAX_FIELDS)
 	{
-		sprintf(errMsg,FIELD_COUNT_ERROR);
+		snprintf(errMsg,MAX_ERR_MSG,FIELD_COUNT_ERROR);
 		msqlDebug(MOD_ERR,"Too many fileds in query\n");
 		msqlTrace(TRACE_OUT,"msqlSetupFields()");
 		return(-1);
@@ -694,7 +699,8 @@ int msqlSetupFields(cacheEntry,flist, fields)
 			if (res == -2)
 				return(-1);
 		
-			sprintf(errMsg, SYSVAR_ERROR, curField->name);
+			snprintf(errMsg, MAX_ERR_MSG, SYSVAR_ERROR, 
+				curField->name);
 			msqlDebug(MOD_ERR,SYSVAR_ERROR, curField->name);
 			return(-1);
 		}
@@ -744,7 +750,8 @@ int msqlSetupFields(cacheEntry,flist, fields)
 					if(curField->value->type != INT_TYPE&&
 					   curField->value->type != UINT_TYPE)
 					{
-						sprintf(errMsg, TYPE_ERROR,
+						snprintf(errMsg, MAX_ERR_MSG,
+							TYPE_ERROR,
 							curField->name);
 						msqlDebug(MOD_ERR, TYPE_ERROR,
 							curField->name);
@@ -758,7 +765,8 @@ int msqlSetupFields(cacheEntry,flist, fields)
 					   curField->value->type != UINT_TYPE&&
 					   curField->value->type != REAL_TYPE)
 					{
-						sprintf(errMsg, TYPE_ERROR,
+						snprintf(errMsg, MAX_ERR_MSG,
+							TYPE_ERROR,
 							curField->name);
 						msqlDebug(MOD_ERR, TYPE_ERROR,
 							curField->name);
@@ -781,7 +789,8 @@ int msqlSetupFields(cacheEntry,flist, fields)
 					}
 					if(curField->value->type != DATE_TYPE)
 					{
-						sprintf(errMsg, TYPE_ERROR,
+						snprintf(errMsg, MAX_ERR_MSG,
+							TYPE_ERROR,
 							curField->name);
 						msqlDebug(MOD_ERR, TYPE_ERROR,
 							curField->name);
@@ -789,8 +798,8 @@ int msqlSetupFields(cacheEntry,flist, fields)
 					}
 					if (curField->value->val.intVal == -1)
 					{
-						sprintf(errMsg, DATE_ERROR,
-							cp);
+						snprintf(errMsg, MAX_ERR_MSG,
+							DATE_ERROR, cp);
 						msqlDebug(MOD_ERR, DATE_ERROR,
 							cp);
 						free(cp);
@@ -811,7 +820,8 @@ int msqlSetupFields(cacheEntry,flist, fields)
 					}
 					if(curField->value->type != TIME_TYPE)
 					{
-						sprintf(errMsg, TYPE_ERROR,
+						snprintf(errMsg, MAX_ERR_MSG,
+							TYPE_ERROR,
 							curField->name);
 						msqlDebug(MOD_ERR, TYPE_ERROR,
 							curField->name);
@@ -819,8 +829,8 @@ int msqlSetupFields(cacheEntry,flist, fields)
 					}
 					if (curField->value->val.intVal == -1)
 					{
-						sprintf(errMsg, TIME_ERROR,
-							cp);
+						snprintf(errMsg, MAX_ERR_MSG,
+							TIME_ERROR, cp);
 						msqlDebug(MOD_ERR, TIME_ERROR,
 							cp);
 						free(cp);
@@ -834,7 +844,8 @@ int msqlSetupFields(cacheEntry,flist, fields)
 					if(curField->value->type != CHAR_TYPE &&
 					   curField->value->type != TEXT_TYPE )
 					{
-						sprintf(errMsg, TYPE_ERROR,
+						snprintf(errMsg, MAX_ERR_MSG,
+							TYPE_ERROR,
 							curField->name);
 						msqlDebug(MOD_ERR, TYPE_ERROR,
 							curField->name);
@@ -851,7 +862,8 @@ int msqlSetupFields(cacheEntry,flist, fields)
 					}
 					if(curField->value->type != REAL_TYPE)
 					{
-						sprintf(errMsg, TYPE_ERROR,
+						snprintf(errMsg, MAX_ERR_MSG,
+							TYPE_ERROR,
 							curField->name);
 						msqlDebug(MOD_ERR, TYPE_ERROR,
 							curField->name);
@@ -866,8 +878,8 @@ int msqlSetupFields(cacheEntry,flist, fields)
 	    {
 		if (curField->table)
 		{
-		    sprintf(errMsg,BAD_FIELD_ERROR, curField->table,
-			curField->name);
+		    snprintf(errMsg,MAX_ERR_MSG, BAD_FIELD_ERROR, 
+			curField->table, curField->name);
 		    msqlDebug(MOD_ERR,"Unknown field \"%s.%s\"\n",
 				curField->table,curField->name);
 		    msqlTrace(TRACE_OUT,"msqlSetupFields()");
@@ -875,7 +887,8 @@ int msqlSetupFields(cacheEntry,flist, fields)
 		}
 		else
 		{
-		    sprintf(errMsg,BAD_FIELD_2_ERROR,curField->name);
+		    snprintf(errMsg,MAX_ERR_MSG, BAD_FIELD_2_ERROR,
+			curField->name);
 		    msqlDebug(MOD_ERR,"Unknown field \"%s\"\n",curField->name);
 		    msqlTrace(TRACE_OUT,"msqlSetupFields()");
 		    return(-1);
@@ -901,7 +914,6 @@ int msqlSetCondValueType(curCond, value)
 
 	if (value->nullVal)
 	{
-		value->type = curCond->type;
 		return(0);
 	}
 	if (value->type == IDENT_TYPE)
@@ -916,7 +928,7 @@ int msqlSetCondValueType(curCond, value)
 				intVal = __msqlScanDate(value->val.charVal);
 				if (intVal == -1)
 				{
-					sprintf(errMsg,DATE_ERROR, 
+					snprintf(errMsg,MAX_ERR_MSG,DATE_ERROR, 
 						curCond->name);
 					return(-1);
 				}
@@ -932,7 +944,7 @@ int msqlSetCondValueType(curCond, value)
 				intVal = __msqlScanTime(value->val.charVal);
 				if (intVal == -1)
 				{
-					sprintf(errMsg,TIME_ERROR, 
+					snprintf(errMsg,MAX_ERR_MSG,TIME_ERROR, 
 						curCond->name);
 					return(-1);
 				}
@@ -999,7 +1011,7 @@ int msqlSetCondValueType(curCond, value)
 		valType = getSysVarType(value->val.identVal->seg2);
 		if (valType < 0)
 		{
-			sprintf(errMsg,SYSVAR_ERROR, 
+			snprintf(errMsg,MAX_ERR_MSG,SYSVAR_ERROR, 
 				value->val.identVal->seg2);
 			return(-1);
 		}
@@ -1009,7 +1021,7 @@ int msqlSetCondValueType(curCond, value)
 		!( curCond->type == TEXT_TYPE && 
 		   valType == CHAR_TYPE))
 	{
-		sprintf(errMsg,BAD_TYPE_ERROR, curCond->name);
+		snprintf(errMsg,MAX_ERR_MSG,BAD_TYPE_ERROR, curCond->name);
 		msqlDebug(MOD_ERR,"Bad type for comparison of '%s'",
                                 curCond->name);
 		return(-1);
@@ -1068,7 +1080,7 @@ int msqlSetupConds(cacheEntry,conds)
 	}
 	if (numConds > MAX_FIELDS)
 	{
-		sprintf(errMsg,COND_COUNT_ERROR);
+		snprintf(errMsg,MAX_ERR_MSG,COND_COUNT_ERROR);
 		msqlDebug(MOD_ERR,"Too many fields in condition\n");
 		msqlTrace(TRACE_OUT,"msqlSetupConds()");
 		return(-1);
@@ -1095,7 +1107,8 @@ int msqlSetupConds(cacheEntry,conds)
 			{
 				if (res == -2)
 					return(-1);
-                        	sprintf(errMsg, SYSVAR_ERROR, curCond->name);
+                        	snprintf(errMsg, MAX_ERR_MSG, SYSVAR_ERROR, 
+					curCond->name);
                         	msqlDebug(MOD_ERR,SYSVAR_ERROR, curCond->name);
 				return(-1);
 			}
@@ -1140,7 +1153,8 @@ int msqlSetupConds(cacheEntry,conds)
 		}
 		if (!fieldDef)
 		{
-			sprintf(errMsg,BAD_FIELD_2_ERROR, curCond->name);
+			snprintf(errMsg, MAX_ERR_MSG, BAD_FIELD_2_ERROR, 
+				curCond->name);
 			msqlDebug(MOD_ERR,
 				"Unknown field in where clause \"%s\"\n",
 				curCond->name);
@@ -1193,7 +1207,7 @@ int msqlSetupOrder(cacheEntry,olist, order)
 	}
 	if (numOrder > MAX_FIELDS)
 	{
-		sprintf(errMsg,ORDER_COUNT_ERROR);
+		snprintf(errMsg,MAX_ERR_MSG,ORDER_COUNT_ERROR);
 		msqlDebug(MOD_ERR,"Too many fields in order specification\n");
 		msqlTrace(TRACE_OUT,"msqlSetupOrder()");
 		return(-1);
@@ -1234,7 +1248,7 @@ int msqlSetupOrder(cacheEntry,olist, order)
 		}
 		if (!fieldDef)
 		{
-			sprintf(errMsg,
+			snprintf(errMsg, MAX_ERR_MSG,
 				cacheEntry->result==0?
 				BAD_FIELD_2_ERROR:BAD_ORD_FIELD_2_ERROR,
 				curOrder->name);
@@ -1425,10 +1439,10 @@ int msqlInit(db)
 	struct	stat buf;
 
 	msqlTrace(TRACE_IN,"msqlInit()");
-	(void)sprintf(path,"%s/msqldb/%s",msqlHomeDir,db);
+	(void)snprintf(path, MAXPATHLEN, "%s/msqldb/%s",msqlHomeDir,db);
 	if (stat(path,&buf) < 0)
 	{
-		sprintf(errMsg,BAD_DB_ERROR,db);
+		snprintf(errMsg, MAX_ERR_MSG, BAD_DB_ERROR,db);
 		msqlDebug(MOD_ERR,"Unknown database \"%s\"\n",db);
 		msqlTrace(TRACE_OUT,"msqlInit()");
 		return(-1);
@@ -1461,7 +1475,8 @@ int msqlServerCreateTable(table,fields,db)
 	/*
 	** Write the catalog entry
 	*/
-	(void)sprintf(defPath,"%s/msqldb/%s/%s.def",msqlHomeDir,db,table);
+	(void)snprintf(defPath, MAXPATHLEN, "%s/msqldb/%s/%s.def",
+		msqlHomeDir,db,table);
 #ifdef OS2
 	fd = _sopen(defPath,O_RDONLY,SH_DENYNO, S_IREAD | S_IWRITE);
 #else
@@ -1470,7 +1485,7 @@ int msqlServerCreateTable(table,fields,db)
 	if (fd >= 0)
 	{
 		(void)close(fd);
-		sprintf(errMsg,TABLE_EXISTS_ERROR,table);
+		snprintf(errMsg,MAX_ERR_MSG,TABLE_EXISTS_ERROR,table);
 		msqlDebug(MOD_ERR,"Table \"%s\" exists\n",table);
 		msqlTrace(TRACE_OUT,"msqlCreate()");
 		return(-1);
@@ -1483,7 +1498,7 @@ int msqlServerCreateTable(table,fields,db)
 #endif
 	if (fd < 0)
 	{
-		sprintf(errMsg,TABLE_FAIL_ERROR,table);
+		snprintf(errMsg,MAX_ERR_MSG,TABLE_FAIL_ERROR,table);
 		msqlDebug(MOD_ERR,"Can't create table \"%s\"\n",table);
 		msqlTrace(TRACE_OUT,"msqlCreate()");
 		return(-1);
@@ -1504,7 +1519,7 @@ int msqlServerCreateTable(table,fields,db)
 	{
 		close(fd);
 		unlink(defPath);
-		sprintf(errMsg,TABLE_WIDTH_ERROR,MAX_FIELDS);
+		snprintf(errMsg,MAX_ERR_MSG,TABLE_WIDTH_ERROR,MAX_FIELDS);
 		msqlDebug(MOD_ERR,"Too many fields in table (%d Max)\n",
 			MAX_FIELDS);
 		msqlTrace(TRACE_OUT,"msqlCreate()");
@@ -1521,7 +1536,7 @@ int msqlServerCreateTable(table,fields,db)
 		{
 			(void)close(fd);
 			unlink(defPath);
-			sprintf(errMsg,CATALOG_WRITE_ERROR);
+			snprintf(errMsg,MAX_ERR_MSG,CATALOG_WRITE_ERROR);
 			msqlDebug(MOD_ERR,"Error writing catalog\n");
 			msqlTrace(TRACE_OUT,"msqlCreate()");
 			return(-1);
@@ -1535,7 +1550,8 @@ int msqlServerCreateTable(table,fields,db)
 	** Create an empty table
 	*/
 	
-	(void)sprintf(datPath,"%s/msqldb/%s/%s.dat",msqlHomeDir,db,table);
+	(void)snprintf(datPath,MAXPATHLEN, "%s/msqldb/%s/%s.dat",
+		msqlHomeDir,db,table);
 	(void)unlink(datPath);
 #ifdef OS2
         fd = _sopen(datPath,O_CREAT | O_WRONLY | O_BINARY, SH_DENYNO, 
@@ -1547,7 +1563,8 @@ int msqlServerCreateTable(table,fields,db)
 	{
 		unlink(datPath);
 		unlink(defPath);
-		sprintf(errMsg,DATA_FILE_ERROR,table, (char*)strerror(errno));
+		snprintf(errMsg, MAX_ERR_MSG,DATA_FILE_ERROR,table, 
+			(char*)strerror(errno));
 		msqlDebug(MOD_ERR,"Error creating table file for \"%s\"\n",
 			table);
 		msqlTrace(TRACE_OUT,"msqlCreate()");
@@ -1562,7 +1579,8 @@ int msqlServerCreateTable(table,fields,db)
 		close(fd);
 		unlink(datPath);
 		unlink(defPath);
-		sprintf(errMsg,DATA_FILE_ERROR,table, (char*)strerror(errno));
+		snprintf(errMsg, MAX_ERR_MSG, DATA_FILE_ERROR,table, 
+			(char*)strerror(errno));
 		msqlDebug(MOD_ERR,"Error creating table file for \"%s\"\n",
 			table);
 		msqlTrace(TRACE_OUT,"msqlCreate()");
@@ -1575,7 +1593,8 @@ int msqlServerCreateTable(table,fields,db)
 	** Create an empty index def file
 	*/
 	
-	(void)sprintf(idxPath,"%s/msqldb/%s/%s.idx",msqlHomeDir,db,table);
+	(void)snprintf(idxPath, MAXPATHLEN, "%s/msqldb/%s/%s.idx",
+		msqlHomeDir,db,table);
 	(void)unlink(idxPath);
 #ifdef OS2
         fd = _sopen(idxPath,O_CREAT | O_WRONLY | O_BINARY, SH_DENYNO, 
@@ -1587,7 +1606,8 @@ int msqlServerCreateTable(table,fields,db)
 	{
 		unlink(datPath);
 		unlink(defPath);
-		sprintf(errMsg,DATA_FILE_ERROR,table, (char*)strerror(errno));
+		snprintf(errMsg,MAX_ERR_MSG,DATA_FILE_ERROR,table, 
+			(char*)strerror(errno));
 		msqlDebug(MOD_ERR,"Error creating table file for \"%s\"\n",
 			table);
 		msqlTrace(TRACE_OUT,"msqlCreate()");
@@ -1598,7 +1618,8 @@ int msqlServerCreateTable(table,fields,db)
 	/*
 	** Create an empty overflow file
 	*/
-	(void)sprintf(oflPath,"%s/msqldb/%s/%s.ofl",msqlHomeDir,db,table);
+	(void)snprintf(oflPath,MAXPATHLEN,"%s/msqldb/%s/%s.ofl",
+		msqlHomeDir,db,table);
 	(void)unlink(oflPath);
 #ifdef OS2
         fd = _sopen(oflPath,O_CREAT | O_WRONLY | O_BINARY, SH_DENYNO, 
@@ -1611,7 +1632,8 @@ int msqlServerCreateTable(table,fields,db)
 		unlink(datPath);
 		unlink(defPath);
 		unlink(idxPath);
-		sprintf(errMsg,DATA_FILE_ERROR,table, (char*)strerror(errno));
+		snprintf(errMsg,MAX_ERR_MSG,DATA_FILE_ERROR,table, 
+			(char*)strerror(errno));
 		msqlDebug(MOD_ERR,"Error creating table file for \"%s\"\n",
 			table);
 		msqlTrace(TRACE_OUT,"msqlCreate()");
@@ -1624,7 +1646,8 @@ int msqlServerCreateTable(table,fields,db)
 		unlink(datPath);
 		unlink(defPath);
 		unlink(idxPath);
-		sprintf(errMsg,DATA_FILE_ERROR,table, (char*)strerror(errno));
+		snprintf(errMsg,MAX_ERR_MSG,DATA_FILE_ERROR,table, 
+			(char*)strerror(errno));
 		msqlDebug(MOD_ERR,"Error creating table file for \"%s\"\n",
 			table);
 		msqlTrace(TRACE_OUT,"msqlCreate()");
@@ -1633,7 +1656,7 @@ int msqlServerCreateTable(table,fields,db)
 	close(fd);
 
 	
-	sprintf(packet,"1:\n");
+	strcpy(packet,"1:\n");
 	writePkt(outSock);
 	msqlTrace(TRACE_OUT,"msqlCreate()");
 	return(0);
@@ -1699,7 +1722,7 @@ static int msqlServerBulkIndex(index,db)
         	}
         	if (res == 0)
         	{
-                	sprintf(errMsg,KEY_UNIQ_ERROR);
+                	snprintf(errMsg,MAX_ERR_MSG,KEY_UNIQ_ERROR);
                 	msqlDebug(MOD_ERR,
 				"Non unique value for unique index\n");
                 	msqlTrace(TRACE_OUT,"msqlServerBulkIndex()");
@@ -1708,7 +1731,7 @@ static int msqlServerBulkIndex(index,db)
 		insertIndex(entry, entry->def, rowNum, idx);
 		rowNum++;
 	}
-	sprintf(packet,"1:\n");
+	strcpy(packet,"1:\n");
 	writePkt(outSock);
         msqlTrace(TRACE_OUT,"msqlServerBulkIndex()");
 	return(0);
@@ -1758,7 +1781,7 @@ int msqlServerCreateIndex(index,fields,db)
 			continue;
 		}
 
-		sprintf(errMsg,"Bad index name");
+		strcpy(errMsg,"Bad index name");
 		msqlTrace(TRACE_OUT,"msqlCreateIndex()");
 		return(-1);
 	}
@@ -1766,11 +1789,11 @@ int msqlServerCreateIndex(index,fields,db)
 	/*
 	** Can't clash with another index either
 	*/
-	(void)sprintf(defPath,"%s/msqldb/%s/%s.idx",msqlHomeDir,db,
-		index->table);
+	(void)snprintf(defPath,MAXPATHLEN,"%s/msqldb/%s/%s.idx",msqlHomeDir,
+		db, index->table);
 
-	(void)sprintf(idxPath,"%s/msqldb/%s/%s.idx-%s",msqlHomeDir,db,
-		index->table, index->name);
+	(void)snprintf(idxPath,MAXPATHLEN,"%s/msqldb/%s/%s.idx-%s",
+		msqlHomeDir,db, index->table, index->name);
 
 #ifdef OS2
         fd = _sopen(defPath,O_RDWR | O_CREAT | O_BINARY, SH_DENYNO, 
@@ -1781,7 +1804,7 @@ int msqlServerCreateIndex(index,fields,db)
 	if (fd < 0)
 	{
 		(void)close(fd);
-		sprintf(errMsg,"Can't open index definition file");
+		strcpy(errMsg,"Can't open index definition file");
 		msqlTrace(TRACE_OUT,"msqlCreateIndex()");
 		return(-1);
 	}
@@ -1793,7 +1816,7 @@ int msqlServerCreateIndex(index,fields,db)
 		if (strcmp(tmp.name, index->name) != 0)
 			continue;
 		
-		sprintf(errMsg,"Bad index name");
+		strcpy(errMsg,"Bad index name");
 		msqlTrace(TRACE_OUT,"msqlCreateIndex()");
 		close(fd);
 		return(-1);
@@ -1826,14 +1849,15 @@ int msqlServerCreateIndex(index,fields,db)
 		}
 		if (!curField)
 		{
-			sprintf(errMsg,"Unknown field '%s'",indexField->name);
+			snprintf(errMsg,MAX_ERR_MSG,"Unknown field '%s'",
+				indexField->name);
 			msqlTrace(TRACE_OUT,"msqlCreateIndex()");
 			close(fd);
 			return(-1);
 		}
 		if (curField->type == TEXT_TYPE)
 		{
-			sprintf(errMsg,"Can't index on a TEXT field!");
+			strcpy(errMsg,"Can't index on a TEXT field!");
 			msqlTrace(TRACE_OUT,"msqlCreateIndex()");
 			close(fd);
 			return(-1);
@@ -1843,7 +1867,7 @@ int msqlServerCreateIndex(index,fields,db)
 		length += curField->length;
 		if(fieldCount > MAX_INDEX_WIDTH - 1)
 		{
-			sprintf(errMsg,"Too many fields in index");
+			strcpy(errMsg,"Too many fields in index");
 			msqlTrace(TRACE_OUT,"msqlCreateIndex()");
 			close(fd);
 			return(-1);
@@ -1891,7 +1915,7 @@ int msqlServerCreateIndex(index,fields,db)
 	{
 		return(msqlServerBulkIndex(index,db));
 	}
-	sprintf(packet,"1:\n");
+	strcpy(packet,"1:\n");
 	writePkt(outSock);
 	msqlTrace(TRACE_OUT,"msqlCreateIndex()");
 	return(0);
@@ -1918,14 +1942,15 @@ int msqlServerDropSequence(table,db)
 	}
 	if (entry->sblk->sequence.step == 0)
 	{
-		sprintf(errMsg,"Table '%s' does not have a sequence",table);
+		snprintf(errMsg,MAX_ERR_MSG,
+			"Table '%s' does not have a sequence",table);
 		msqlTrace(TRACE_OUT,"msqlCreateSequence()");
 		return(-1);
 	}
 
 	entry->sblk->sequence.step = 0;
 	entry->sblk->sequence.value = 0;
-	sprintf(packet,"1:\n");
+	strcpy(packet,"1:\n");
 	writePkt(outSock);
 	msqlTrace(TRACE_OUT,"msqlCreateSequence()");
 	return(0);
@@ -1953,14 +1978,15 @@ int msqlServerCreateSequence(table,step,val,db)
 	}
 	if (entry->sblk->sequence.step != 0)
 	{
-		sprintf(errMsg,"Table '%s' already has a sequence",table);
+		snprintf(errMsg,MAX_ERR_MSG,
+			"Table '%s' already has a sequence",table);
 		msqlTrace(TRACE_OUT,"msqlCreateSequence()");
 		return(-1);
 	}
 
 	entry->sblk->sequence.step = step;
 	entry->sblk->sequence.value = val;
-	sprintf(packet,"1:\n");
+	strcpy(packet,"1:\n");
 	writePkt(outSock);
 	msqlTrace(TRACE_OUT,"msqlCreateSequence()");
 	return(0);
@@ -2003,7 +2029,8 @@ int msqlServerDropTable(table,db)
 	/*
 	** Now blow away the table files
 	*/
-	(void)sprintf(path,"%s/msqldb/%s/%s.def",msqlHomeDir,db,table);
+	(void)snprintf(path,MAXPATHLEN,"%s/msqldb/%s/%s.def",msqlHomeDir,
+		db,table);
 #ifdef OS2
 	fp = fopen(path,"rb");
 #else
@@ -2011,22 +2038,25 @@ int msqlServerDropTable(table,db)
 #endif
 	if (!fp)
 	{
-		sprintf(errMsg,BAD_TABLE_ERROR,table);
+		snprintf(errMsg,MAX_ERR_MSG,BAD_TABLE_ERROR,table);
 		msqlDebug(MOD_ERR,"Unknown table \"%s\"\n",table);
 		msqlTrace(TRACE_OUT,"msqlDrop()");
 		return(-1);
 	}
 	(void)fclose(fp);
 	unlink(path);
-	(void)sprintf(path,"%s/msqldb/%s/%s.dat",msqlHomeDir,db,table);
+	(void)snprintf(path,MAXPATHLEN,"%s/msqldb/%s/%s.dat",msqlHomeDir,
+		db,table);
 	unlink(path);
-	(void)sprintf(path,"%s/msqldb/%s/%s.ofl",msqlHomeDir,db,table);
+	(void)snprintf(path,MAXPATHLEN,"%s/msqldb/%s/%s.ofl",msqlHomeDir,
+		db,table);
 	unlink(path);
 
 	/*
 	** Take care of the index files.
 	*/
-	(void)sprintf(defPath,"%s/msqldb/%s/%s.idx",msqlHomeDir,db,table);
+	(void)snprintf(defPath,MAXPATHLEN,"%s/msqldb/%s/%s.idx",msqlHomeDir,
+		db,table);
 #ifdef OS2
         fd = _sopen(defPath,O_RDONLY | O_BINARY, SH_DENYNO, S_IREAD | S_IWRITE);
 #else
@@ -2036,7 +2066,8 @@ int msqlServerDropTable(table,db)
 	{
 		while(read(fd,&tmp,sizeof(tmp)) == sizeof(tmp))
 		{
-			(void)sprintf(path,"%s/msqldb/%s/%s.idx-%s",
+			(void)snprintf(path,MAXPATHLEN,
+				"%s/msqldb/%s/%s.idx-%s",
 				msqlHomeDir,db,table,tmp.name);
 			unlink(path);
 		}
@@ -2044,7 +2075,7 @@ int msqlServerDropTable(table,db)
 	}
 	unlink(defPath);
 
-	sprintf(packet,"1:\n");
+	strcpy(packet,"1:\n");
 	writePkt(outSock);
 	msqlTrace(TRACE_OUT,"msqlDrop()");
 	return(0);
@@ -2076,8 +2107,8 @@ int msqlServerDropIndex(index,db)
 		return(-1);
 	}
 
-	(void)sprintf(defPath,"%s/msqldb/%s/%s.idx",msqlHomeDir,db,
-		index->table);
+	(void)snprintf(defPath,MAXPATHLEN,"%s/msqldb/%s/%s.idx",msqlHomeDir,
+		db, index->table);
 #ifdef OS2
         in = _sopen(defPath,O_RDONLY | O_BINARY, SH_DENYNO, S_IREAD | S_IWRITE);
 #else
@@ -2085,12 +2116,13 @@ int msqlServerDropIndex(index,db)
 #endif
 	if (in < 0)
 	{
-		sprintf(errMsg,"No indices defined for '%s'",index->table);
+		snprintf(errMsg,MAX_ERR_MSG,"No indices defined for '%s'",
+			index->table);
 		msqlTrace(TRACE_OUT,"msqlDropIndex()");
 		return(-1);
 	}
-	(void)sprintf(tmpPath,"%s/msqldb/%s/%s.idx-tmp",msqlHomeDir,db,
-		index->table);
+	(void)snprintf(tmpPath,MAXPATHLEN,"%s/msqldb/%s/%s.idx-tmp",
+		msqlHomeDir,db, index->table);
 #ifdef OS2
         out = _sopen(tmpPath,O_RDWR | O_CREAT | O_BINARY, SH_DENYNO, 
 		S_IREAD | S_IWRITE);
@@ -2100,7 +2132,7 @@ int msqlServerDropIndex(index,db)
 	if (out < 0)
 	{
 		(void)close(in);
-		sprintf(errMsg,"Can't create index copy file");
+		strcpy(errMsg,"Can't create index copy file");
 		msqlTrace(TRACE_OUT,"msqlDropIndex()");
 		return(-1);
 	}
@@ -2128,8 +2160,8 @@ int msqlServerDropIndex(index,db)
 	close(out);
 	if (!found)
 	{
-		sprintf(errMsg,"Unknown index '%s' for '%s'",index->name, 
-			index->table);
+		snprintf(errMsg,MAX_ERR_MSG, "Unknown index '%s' for '%s'",
+			index->name, index->table);
 		unlink(tmpPath);
 		msqlTrace(TRACE_OUT,"msqlDropIndex()");
 		return(-1);
@@ -2140,7 +2172,7 @@ int msqlServerDropIndex(index,db)
 	*/
 	unlink(defPath);
 	rename(tmpPath,defPath);
-	sprintf(tmpPath,"%s/msqldb/%s/%s.idx-%s",msqlHomeDir,db,
+	snprintf(tmpPath,MAXPATHLEN,"%s/msqldb/%s/%s.idx-%s",msqlHomeDir,db,
                 index->table, index->name);
 	unlink(tmpPath);
 
@@ -2150,7 +2182,7 @@ int msqlServerDropIndex(index,db)
 
 	invalidateCacheEntry(entry);
 
-	sprintf(packet,"1:\n");
+	strcpy(packet,"1:\n");
 	writePkt(outSock);
 	msqlTrace(TRACE_OUT,"msqlDropIndex()");
 	return(0);
@@ -2294,7 +2326,7 @@ int msqlServerDelete(table,conds,db)
 		}
 		rowNum = getCandidate(cacheEntry,candidate);
 	}
-	sprintf(packet,"%d:\n",count);
+	snprintf(packet,PKT_LEN,"%d:\n",count);
 	writePkt(outSock);
 	msqlTrace(TRACE_OUT,"msqlServerDelete()");
 	freeCandidate(candidate);
@@ -2352,7 +2384,8 @@ int msqlServerInsert(table,fields,db)
 	{
 		if (!curField->value)
 		{
-			sprintf(errMsg, NO_VALUE_ERROR, curField->name);
+			snprintf(errMsg,MAX_ERR_MSG,NO_VALUE_ERROR, 
+				curField->name);
 			msqlDebug(MOD_ERR,
 				"No value specified for field '%s'",
 				curField->name);
@@ -2370,7 +2403,8 @@ int msqlServerInsert(table,fields,db)
 			if (strcmp(curField->name,curField2->name) == 0 &&
 			    strcmp(curField->table,curField2->table) == 0)
 			{
-				sprintf(errMsg,NON_UNIQ_ERROR, curField->name);
+				snprintf(errMsg,MAX_ERR_MSG,NON_UNIQ_ERROR, 
+					curField->name);
 				msqlDebug(MOD_ERR,"Field '%s' not unique",
 					curField->name);
 				msqlTrace(TRACE_OUT,"msqlServerInsert()");
@@ -2410,7 +2444,7 @@ int msqlServerInsert(table,fields,db)
 	}
 	if (res == 0)
 	{
-		sprintf(errMsg,KEY_UNIQ_ERROR);
+		strcpy(errMsg,KEY_UNIQ_ERROR);
 		msqlDebug(MOD_ERR,"Non unique value for unique index\n");
 		msqlTrace(TRACE_OUT,"msqlServerInsert()");
 		return(-1);
@@ -2438,14 +2472,15 @@ int msqlServerInsert(table,fields,db)
 	insertIndices(cacheEntry, fields, rowNum);
 	if(rowWrite(cacheEntry,NULL,rowNum) < 0)
 	{
-		sprintf(errMsg,WRITE_ERROR, (char*)strerror(errno));
+		snprintf(errMsg,MAX_ERR_MSG,WRITE_ERROR, 
+			(char*)strerror(errno));
 		msqlDebug(MOD_ERR,"Error on data write\n");
 		msqlTrace(TRACE_OUT,"msqlServerInsert()");
 		return(-1);
 	}
 	cacheEntry->sblk->activeRows++;
 	
-	sprintf(packet,"1:\n");
+	strcpy(packet,"1:\n");
 	writePkt(outSock);
 	msqlTrace(TRACE_OUT,"msqlServerInsert()");
 	return(0);
@@ -2468,7 +2503,6 @@ int msqlServerUpdate(table,fields,conds,db)
 	row_t	row;
 	cache_t	*cacheEntry;
 	cand_t	*candidate;
-	field_t	*curField;
 	
 
 
@@ -2543,6 +2577,16 @@ int msqlServerUpdate(table,fields,conds,db)
 				freeCandidate(candidate);
 				return(-1);
 			}
+			/*
+			** Force a remap just in case the overflow file
+			** has been extended
+			*/
+			if (initTable(cacheEntry,FULL_REMAP) < 0)
+			{
+				msqlTrace(TRACE_OUT,"msqlServerUpdate()");
+				freeCandidate(candidate);
+				return(-1);
+			}
 			if (checkNullFields(cacheEntry,&row,fullFlist) < 0)
 			{
 				bcopy(cacheEntry->row.buf, row.buf,
@@ -2571,7 +2615,7 @@ int msqlServerUpdate(table,fields,conds,db)
         		{
 				bcopy(cacheEntry->row.buf, row.buf,
 					(cacheEntry->rowLen + HEADER_SIZE));
-                		sprintf(errMsg,KEY_UNIQ_ERROR);
+                		strcpy(errMsg,KEY_UNIQ_ERROR);
                 		msqlDebug(MOD_ERR,
 					"Non unique value for unique index\n");
                 		msqlTrace(TRACE_OUT,"msqlServerUpdate()");
@@ -2580,7 +2624,7 @@ int msqlServerUpdate(table,fields,conds,db)
 
 			if(rowWrite(cacheEntry,&row,rowNum) < 0)
 			{
-				sprintf(errMsg,WRITE_ERROR, 
+				snprintf(errMsg,MAX_ERR_MSG,WRITE_ERROR, 
 					(char*)strerror(errno));
 				msqlDebug(MOD_ERR,"Error on data write\n");
 				msqlTrace(TRACE_OUT,"msqlServerUpdate()");
@@ -2596,11 +2640,18 @@ int msqlServerUpdate(table,fields,conds,db)
 					freeCandidate(candidate);
 					return(-1);
 				}
+				/*
+				** Have to reset this.  If it's an index based
+				** lookup then the delete may have shuffled a 
+				** a dup up the chain.  A getnext would skip the
+				** correct entry.
+				*/
+				resetCandidate(candidate, MSQL_DELETE);
 			}
 		}
 		rowNum = getCandidate(cacheEntry, candidate);
 	}
-	sprintf(packet,"%d:\n",count);
+	snprintf(packet,PKT_LEN,"%d:\n",count);
 	writePkt(outSock);
 	freeCandidate(candidate);
 	msqlTrace(TRACE_OUT,"msqlServerUpdate()");
@@ -2630,12 +2681,12 @@ void formatPacket(packet,fields)
 			switch(curField->type)
 			{
 				case INT_TYPE:
-					sprintf(outBuf,"%d",
+					snprintf(outBuf,sizeof(outBuf),"%d",
 					    curField->value->val.intVal);
 					outData = (u_char *)outBuf;
 					break;
 				case UINT_TYPE:
-					sprintf(outBuf,"%u",
+					snprintf(outBuf,sizeof(outBuf),"%u",
 					    curField->value->val.intVal);
 					outData = (u_char *)outBuf;
 					break;
@@ -2650,7 +2701,7 @@ void formatPacket(packet,fields)
 					outData = (u_char *)outBuf;
 					break;
 				case MONEY_TYPE:
-					printMoney(outBuf,
+					printMoney(outBuf,sizeof(outBuf),
 						curField->value->val.intVal);
 					outData = (u_char *)outBuf;
 					break;
@@ -2659,14 +2710,17 @@ void formatPacket(packet,fields)
 					outData = curField->value->val.charVal;
 					break;
 				case REAL_TYPE:
-					sprintf(realFmt,"%%.%df",
-						   curField->value->precision);
-					sprintf(outBuf,realFmt,
-					    curField->value->val.realVal);
+					snprintf(realFmt,sizeof(realFmt),
+						"%%.%df",
+						curField->value->precision);
+					snprintf(outBuf,sizeof(outBuf),
+						realFmt,
+					    	curField->value->val.realVal);
 					outData = (u_char *)outBuf;
 					break;
 			}
-			sprintf(bufLen,"%d:",(int)strlen((char *)outData));
+			snprintf(bufLen,sizeof(bufLen), "%d:",
+				(int)strlen((char *)outData));
 			strcat(packet,bufLen);
 			strcat(packet,(char *)outData);
 		}
@@ -2722,12 +2776,13 @@ void msqlServerCreateDB(sock,db)
 	** See if the directory exists
 	*/
 
-	(void)sprintf(path,"%s/msqldb/%s", msqlHomeDir, db);
+	(void)snprintf(path,MAXPATHLEN,"%s/msqldb/%s", msqlHomeDir, db);
 	dirp = opendir(path);
 	if (dirp)
 	{
 		closedir(dirp);
-		sprintf(packet,"-1:Error creating database : %s exists!\n",db);
+		snprintf(packet,PKT_LEN, 
+			"-1:Error creating database : %s exists!\n",db);
                 writePkt(sock);
 		return;
 	}
@@ -2741,12 +2796,12 @@ void msqlServerCreateDB(sock,db)
 	if (mkdir(path,0700) < 0)
 #endif
 	{
-		sprintf(packet,"-1:Error creating database (%s)\n",
+		snprintf(packet,PKT_LEN, "-1:Error creating database (%s)\n",
 			(char*)strerror(errno));
 		writePkt(sock);
 		return;
 	}
-	sprintf(packet,"-100:\n");
+	strcpy(packet,"-100:\n");
 	writePkt(sock);
 }
 
@@ -2771,13 +2826,13 @@ void msqlServerCopyDB(sock,fromDB, toDB)
 	** See if the "to" directory exists
 	*/
 
-	(void)sprintf(toPath,"%s/msqldb/%s", msqlHomeDir, toDB);
+	(void)snprintf(toPath,MAXPATHLEN,"%s/msqldb/%s", msqlHomeDir, toDB);
 	dirp = opendir(toPath);
 	if (dirp)
 	{
 		closedir(dirp);
-		sprintf(packet,"-1:Error copying database : %s exists!\n",
-			toDB);
+		snprintf(packet,PKT_LEN,
+			"-1:Error copying database : %s exists!\n", toDB);
                 writePkt(sock);
 		return;
 	}
@@ -2786,11 +2841,12 @@ void msqlServerCopyDB(sock,fromDB, toDB)
 	** See if the "from" directory exists
 	*/
 
-	(void)sprintf(fromPath,"%s/msqldb/%s", msqlHomeDir, fromDB);
+	(void)snprintf(fromPath,MAXPATHLEN, "%s/msqldb/%s", msqlHomeDir, 
+		fromDB);
 	dirp = opendir(fromPath);
 	if (!dirp)
 	{
-		sprintf(packet,
+		snprintf(packet, PKT_LEN,
 			"-1:Error copying database : %s doesn't exist!\n",
 			fromDB);
                 writePkt(sock);
@@ -2806,7 +2862,7 @@ void msqlServerCopyDB(sock,fromDB, toDB)
 	if (mkdir(toPath,0700) < 0)
 #endif
 	{
-		sprintf(packet,"-1:Error creating database (%s)\n",
+		snprintf(packet,PKT_LEN, "-1:Error creating database (%s)\n",
 			(char*)strerror(errno));
 		writePkt(sock);
 		return;
@@ -2820,11 +2876,11 @@ void msqlServerCopyDB(sock,fromDB, toDB)
 	cur = readdir(dirp);
 	while(cur)
 	{
-		sprintf(fromFile,"%s/%s",fromPath,cur->d_name);
-		sprintf(toFile,"%s/%s",toPath,cur->d_name);
+		snprintf(fromFile,MAXPATHLEN,"%s/%s",fromPath,cur->d_name);
+		snprintf(toFile,MAXPATHLEN,"%s/%s",toPath,cur->d_name);
 		if (copyFile(fromFile, toFile) < 0)
 		{
-			sprintf(packet,"-1%s\n",errMsg);
+			snprintf(packet,PKT_LEN,"-1%s\n",errMsg);
 			writePkt(sock);
 			msqlDropDB(-1,toDB);
 			return;
@@ -2832,7 +2888,7 @@ void msqlServerCopyDB(sock,fromDB, toDB)
 		cur = readdir(dirp);
 	}
 
-	sprintf(packet,"-100:\n");
+	strcpy(packet,"-100:\n");
 	writePkt(sock);
 }
 
@@ -2849,12 +2905,13 @@ void msqlServerMoveDB(sock,fromDB, toDB)
 	** See if the "to" directory exists
 	*/
 
-	(void)sprintf(toPath,"%s/msqldb/%s", msqlHomeDir, toDB);
+	(void)snprintf(toPath,MAXPATHLEN,"%s/msqldb/%s", msqlHomeDir, toDB);
 	dirp = opendir(toPath);
 	if (dirp)
 	{
 		closedir(dirp);
-		sprintf(packet,"-1:Error moving database : %s exists!\n",toDB);
+		snprintf(packet,PKT_LEN,
+			"-1:Error moving database : %s exists!\n",toDB);
                 writePkt(sock);
 		return;
 	}
@@ -2863,11 +2920,13 @@ void msqlServerMoveDB(sock,fromDB, toDB)
 	** See if the "from" directory exists
 	*/
 
-	(void)sprintf(fromPath,"%s/msqldb/%s", msqlHomeDir, fromDB);
+	(void)snprintf(fromPath,MAXPATHLEN,"%s/msqldb/%s", msqlHomeDir, 
+		fromDB);
 	dirp = opendir(fromPath);
 	if (!dirp)
 	{
-		sprintf(packet,"-1:Error moving database : %s doesn't exist!\n",
+		snprintf(packet,PKT_LEN, 
+			"-1:Error moving database : %s doesn't exist!\n",
 			fromDB);
                 writePkt(sock);
 		return;
@@ -2879,13 +2938,13 @@ void msqlServerMoveDB(sock,fromDB, toDB)
 	*/
 	if (rename(fromPath, toPath) < 0)
 	{
-		sprintf(packet,"-1:Error moving database (%s)\n",
+		snprintf(packet,PKT_LEN,"-1:Error moving database (%s)\n",
 			(char*)strerror(errno));
 		writePkt(sock);
 		return;
 	}
 	invalidateCachedDatabase(fromDB);
-	sprintf(packet,"-100:\n");
+	strcpy(packet,"-100:\n");
 	writePkt(sock);
 }
 
@@ -2903,21 +2962,19 @@ void msqlServerDropDB(sock,db)
 #else
 	struct	direct *cur;
 #endif
-	int	index;
-	cache_t	*entry;
 
 	/*
 	** See if the directory exists
 	*/
 
-	(void)sprintf(path,"%s/msqldb/%s", msqlHomeDir, db);
+	(void)snprintf(path,MAXPATHLEN,"%s/msqldb/%s", msqlHomeDir, db);
 	dirp = opendir(path);
 	if (!dirp)
 	{
 		if (sock < 0)
 			return;
-		sprintf(packet,"-1:Error dropping database : %s doesn't exist\n"
-			, db);
+		snprintf(packet,PKT_LEN, 
+			"-1:Error dropping database : %s doesn't exist\n",db);
 		writePkt(sock);
 		return;
 	}
@@ -2931,7 +2988,7 @@ void msqlServerDropDB(sock,db)
 	cur = readdir(dirp);
 	while(cur)
 	{
-		sprintf(filePath,"%s/%s",path,cur->d_name);
+		snprintf(filePath,MAXPATHLEN,"%s/%s",path,cur->d_name);
 		unlink(filePath);
 		cur = readdir(dirp);
 	}
@@ -2940,7 +2997,7 @@ void msqlServerDropDB(sock,db)
 	{
 		if (sock < 0)
 			return;
-		sprintf(packet,"-1:Error dropping database\n");
+		snprintf(packet,PKT_LEN,"-1:Error dropping database\n");
 		writePkt(sock);
 		closedir(dirp);
 		return;
@@ -2950,6 +3007,6 @@ void msqlServerDropDB(sock,db)
 	invalidateCachedDatabase(db);
 	if (sock < 0)
 		return;
-	sprintf(packet,"-100:\n");
+	strcpy(packet,"-100:\n");
 	writePkt(sock);
 }
