@@ -4,6 +4,7 @@
 #include <unistd.h>
 #include "msql.h"
 
+#define VERBOSE
 
 #define SELECT_QUERY "select name from test where num = %d"
 
@@ -13,6 +14,9 @@ int main(argc,argv)
 	char	*argv[];
 {
 	int	count,
+		cur,
+                oldTime,
+                curTime,
 		sock,
 		num;
 	char	qbuf[160],
@@ -50,11 +54,12 @@ int main(argc,argv)
 		printf("Couldn't select database %s!\n%s\n",argv[1],msqlErrMsg);
 	}
 
-	count = 0;
+	cur = count = 0;
 	num = atoi(qty);
+        oldTime = time(NULL);
 	while (count < num)
 	{
-		sprintf(qbuf,SELECT_QUERY,count);
+		snprintf(qbuf,sizeof(qbuf),SELECT_QUERY,count);
 		if(msqlQuery(sock,qbuf) < 0)
 		{
 			printf("Query failed (%s)\n",msqlErrMsg);
@@ -62,6 +67,16 @@ int main(argc,argv)
 			exit(1);
 		}
 		count++;
+                cur++;
+                if (cur == 1000)
+                {
+#ifdef VERBOSE
+                        curTime = time(NULL);
+                        printf("%d  (%d seconds)\n",count, curTime - oldTime);
+                        oldTime = curTime;
+#endif
+                        cur = 0;
+                }
 	}
 	msqlClose(sock);
 	exit(0);
