@@ -325,7 +325,7 @@ void checkAuth(level)
 	/*
 	** Connect to the database
 	*/
-	authHost = msqlGetCharConf("w3-msql","auth_host");
+	authHost = (char *)msqlGetCharConf("w3-msql","auth_host");
 	sock = msqlConnect(authHost);
 	if (sock < 0)
 	{
